@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: HTTP
-version: 4000.2.5
-id: HTTP-4000.2.5-cd8b9cedb7cf101615e89651acbe49e7
+version: 4000.2.8
+id: HTTP-4000.2.8-f0521402a0b2a00514705f5569e76353
 
 license: BSD3
 copyright:
@@ -51,25 +51,25 @@ exposed-modules: Network.BufferType Network.Stream
 hidden-modules: Network.HTTP.Base64 Network.HTTP.MD5Aux
                 Network.HTTP.Utils Paths_HTTP
 trusted: False
-import-dirs: /usr/local/lib/ghc/HTTP-4000.2.5
-library-dirs: /usr/local/lib/ghc/HTTP-4000.2.5
-hs-libraries: HSHTTP-4000.2.5
+import-dirs: /usr/local/lib/ghc/HTTP-4000.2.8
+library-dirs: /usr/local/lib/ghc/HTTP-4000.2.8
+hs-libraries: HSHTTP-4000.2.8
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
-         old-time-1.1.0.0-3e0f7b48d6c1d1415ad852e23725fdc1
-         parsec-3.1.3-fb970d7908f363dfef34b141200235e6
+depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         network-2.4.1.2-2410fd33cfc22dd877d4b24516181434
+         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
+         parsec-3.1.3-8bc25b86282839a5b5fcb3c428bb3b9c
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.2.5/html/HTTP.haddock
-haddock-html: /usr/local/share/doc/hs-HTTP-4000.2.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.2.8/html/HTTP.haddock
+haddock-html: /usr/local/share/doc/hs-HTTP-4000.2.8/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
